class NotSupportedFileTypeError(Exception):
    ...


class FileNotExistsError(Exception):
    ...


class InvalidEventError(Exception):
    ...


class UnsupportedOpenAPIVersion(Exception):
    ...


class UnhandledValidationError(Exception):
    ...
